@@ -1,7 +1,9 @@
 from typing import List, Any
 import os
 
-def searchFiles(keyword: str , path: str):
+
+def searchFiles(keyword: str, path: str):
+    """Search for files"""
     files: List[Any] = []
     for root, dirs, files in os.walk(path):
         for file in files:
@@ -9,7 +11,9 @@ def searchFiles(keyword: str , path: str):
                 files.append(root + '\\' + str(file))
     return files
 
+
 def searchDirs(keyword: str, path: str):
+    """Search for folders"""
     folders = []
     for root, dirs, files in os.walk(path):
         for dir in dirs:
@@ -17,7 +21,9 @@ def searchDirs(keyword: str, path: str):
                 folders.append(root + '\\' + str(dir))
     return folders
 
+
 def searchExts(ext: str, path: str):
+    """Search for extensions"""
     files: List[Any] = []
     for root, dirs, files in os.walk(path):
         for file in files:
@@ -25,20 +31,18 @@ def searchExts(ext: str, path: str):
                 files.append(root + '\\' + str(file))
     return files
 
+
 def searchList(listOfTerms, query: str, filter='in'):
+    """Search within a list"""
     matches = []
     for item in listOfTerms:
-        if filter == 'in':
-            if query in item:
-                matches.append(item)
-        elif filter == 'start':
-            if item.startswith(query):
-                matches.append(item)
-        elif filter == 'end':
-            if item.endswith(query):
-                matches.append(item)
-        elif filter == 'exact':
-            if item == query:
-                matches.append(item)
+        if filter == 'in' and query in item:
+            matches.append(item)
+        elif filter == 'start' and item.startswith(query):
+            matches.append(item)
+        elif filter == 'end' and item.endswith(query):
+            matches.append(item)
+        elif filter == 'exact' and item == query:
+            matches.append(item)
 
     return matches
