@@ -1,18 +1,20 @@
 from typing import List
 
-'''
+"""
 Super Encrypt - Encryption Algorithm with 4 key encryption and decryption
 
 __author__ = "PyBash"
 __version__ = "v1.0.0"
-'''
+"""
 import random
 from . import error
 
 BASE_LETTERS: str = 'abcdefghijklmnopqrstuvwxyz'
 BASE_SYMBOLS: str = ' 1234567890!@#$%^&*()-_=+[{]};:\'"<,>.?/`~|\\'
 
+
 def genCharKeys() -> List[str]:
+    """Generates character keys"""
     base: List[str] = list(BASE_LETTERS)
     random.shuffle(base)
     key1 = ''.join(base)
@@ -29,13 +31,17 @@ def genCharKeys() -> List[str]:
     keyList.append(key4)
     return keyList
 
+
 def genSymKey() -> str:
+    """Generates symbol key"""
     base: List[str] = list(BASE_SYMBOLS)
     random.shuffle(base)
     key: str = ''.join(base)
     return key
 
+
 def checkCharKeys(keyList: List[str]):
+    """Validates character keys"""
     key1 = keyList[0].replace("\n", '')
     key2 = keyList[1].replace("\n", '')
     key3 = keyList[2].replace("\n", '')
@@ -51,28 +57,33 @@ def checkCharKeys(keyList: List[str]):
     key3 = "".join(key3Sorted)
     key4 = "".join(key4Sorted)
     base = "".join(baseSorted)
-    
+
     if key1 != base:
         raise error.InvalidKeyListError()
-    elif key2 != base:
+    if key2 != base:
         raise error.InvalidKeyListError()
-    elif key3 != base:
+    if key3 != base:
         raise error.InvalidKeyListError()
-    elif key4 != base:
+    if key4 != base:
         raise error.InvalidKeyListError()
-    
-def checkSymKey(symKey: str): 
+
+
+def checkSymKey(symKey: str):
+    """Validates symbol key"""
     sym: str = symKey
     base: str = BASE_SYMBOLS
     symSorted: List[str] = sorted(sym)
     baseSorted: List[str] = sorted(base)
     sym = "".join(symSorted)
     base = "".join(baseSorted)
-    
+
     if sym != base:
         raise error.InvalidSymbolKeyError()
 
+
 class SuperEncrypt():
+    """Class for performing operations"""
+
     def __init__(self, keyCharList: List[str], keySym: str):
         self.keyCharList: List[str] = keyCharList
         self.key1 = self.keyCharList[0]
@@ -82,15 +93,16 @@ class SuperEncrypt():
         self.key5: str = keySym
 
     def encrypt(self, msg: str) -> str:
+        """Encrypt data"""
         encrypted1: str = ''
         encrypted2: str = ''
         encrypted3: str = ''
         encrypted4: str = ''
         encryptedSym: str = ''
-        
+
         checkCharKeys(self.keyCharList)
         checkSymKey(self.key5)
-        
+
         for char in msg:
             actualChars: str = BASE_LETTERS
             encryptedChars: str = self.key1
@@ -103,7 +115,7 @@ class SuperEncrypt():
                     encrypted1 += char.replace(char, encryptedElem.upper())
                 else:
                     encrypted1 += char.replace(char, encryptedElem)
-        
+
         for char in encrypted1:
             actualChars = BASE_LETTERS
             encryptedChars = self.key2
@@ -116,7 +128,7 @@ class SuperEncrypt():
                     encrypted2 += char.replace(char, encryptedElem.upper())
                 else:
                     encrypted2 += char.replace(char, encryptedElem)
-        
+
         for char in encrypted2:
             actualChars = BASE_LETTERS
             encryptedChars = self.key3
@@ -129,7 +141,7 @@ class SuperEncrypt():
                     encrypted3 += char.replace(char, encryptedElem.upper())
                 else:
                     encrypted3 += char.replace(char, encryptedElem)
-        
+
         for char in encrypted3:
             actualChars = BASE_LETTERS
             encryptedChars = self.key4
@@ -142,7 +154,7 @@ class SuperEncrypt():
                     encrypted4 += char.replace(char, encryptedElem.upper())
                 else:
                     encrypted4 += char.replace(char, encryptedElem)
-        
+
         for char in encrypted4:
             actualChars = BASE_SYMBOLS
             encryptedChars = self.key5
@@ -155,19 +167,20 @@ class SuperEncrypt():
                     encryptedSym += char.replace(char, encryptedElem.upper())
                 else:
                     encryptedSym += char.replace(char, encryptedElem)
-        
+
         return encryptedSym
 
     def decrypt(self, msg: str) -> str:
+        """Decrypt data"""
         decrypted4: str = ''
         decrypted3: str = ''
         decrypted2: str = ''
         decrypted1: str = ''
         decryptedSym: str = ''
-        
+
         checkCharKeys(self.keyCharList)
         checkSymKey(self.key5)
-        
+
         for char in msg:
             actualChars = self.key4
             decryptedChars: str = BASE_LETTERS
@@ -180,7 +193,7 @@ class SuperEncrypt():
                     decrypted4 += char.replace(char, decryptedElem.upper())
                 else:
                     decrypted4 += char.replace(char, decryptedElem)
-        
+
         for char in decrypted4:
             actualChars = self.key3
             decryptedChars = BASE_LETTERS
@@ -193,7 +206,7 @@ class SuperEncrypt():
                     decrypted3 += char.replace(char, decryptedElem.upper())
                 else:
                     decrypted3 += char.replace(char, decryptedElem)
-        
+
         for char in decrypted3:
             actualChars = self.key2
             decryptedChars = BASE_LETTERS
@@ -206,7 +219,7 @@ class SuperEncrypt():
                     decrypted2 += char.replace(char, decryptedElem.upper())
                 else:
                     decrypted2 += char.replace(char, decryptedElem)
-        
+
         for char in decrypted2:
             actualChars = self.key1
             decryptedChars = BASE_LETTERS
@@ -219,7 +232,7 @@ class SuperEncrypt():
                     decrypted1 += char.replace(char, decryptedElem.upper())
                 else:
                     decrypted1 += char.replace(char, decryptedElem)
-        
+
         for char in decrypted1:
             actualChars = self.key5
             decryptedChars = BASE_SYMBOLS
