@@ -1,233 +1,297 @@
 # Mass
 class mg:
+    """Milligram class"""
+
     def __init__(self):
         self.name: str = 'MilliGram'
         self.unit: str = 'mg'
-    
+
     def __repr__(self) -> str:
         return f'mg(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class cg:
+    """Centigram class"""
+
     def __init__(self):
         self.name: str = 'CentiGram'
         self.unit: str = 'cg'
-    
+
     def __repr__(self) -> str:
         return f'cg(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class dg:
+    """Decigram class"""
+
     def __init__(self):
         self.name: str = 'DeciGram'
         self.unit: str = 'dg'
-    
+
     def __repr__(self) -> str:
         return f'dg(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class g:
+    """Gram class"""
+
     def __init__(self):
         self.name: str = 'Gram'
         self.unit: str = 'g'
-    
+
     def __repr__(self) -> str:
         return f'g(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class dag:
+    """Decagram class"""
+
     def __init__(self):
         self.name: str = 'DekaGram'
         self.unit: str = 'dag'
-    
+
     def __repr__(self) -> str:
         return f'dag(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class hg:
+    """Hectagram class"""
+
     def __init__(self):
         self.name: str = 'HectoGram'
         self.unit: str = 'hg'
-    
+
     def __repr__(self) -> str:
         return f'hg(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class kg:
+    """Kilogram class"""
+
     def __init__(self):
         self.name: str = 'KiloGram'
         self.unit: str = 'kg'
-    
+
     def __repr__(self) -> str:
         return f'kg(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
 
 # Volume
+
+
 class ml:
+    """Millilitre class"""
+
     def __init__(self):
         self.name: str = 'MilliLiter'
         self.unit: str = 'ml'
-    
+
     def __repr__(self) -> str:
         return f'ml(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class cl:
+    """Centilitre class"""
+
     def __init__(self):
         self.name: str = 'CentiLiter'
         self.unit: str = 'cl'
-    
+
     def __repr__(self) -> str:
         return f'cl(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class dl:
+    """Decilitre class"""
+
     def __init__(self):
         self.name: str = 'DeciLiter'
         self.unit: str = 'dl'
-    
+
     def __repr__(self) -> str:
         return f'dl(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class l:
+    """Litre class"""
+
     def __init__(self):
         self.name: str = 'Liter'
         self.unit: str = 'l'
-    
+
     def __repr__(self) -> str:
         return f'l(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class dal:
+    """Decalitre class"""
+
     def __init__(self):
         self.name: str = 'DekaLiter'
         self.unit: str = 'da'
-    
+
     def __repr__(self) -> str:
         return f'da(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class hl:
+    """Hectalitre class"""
+
     def __init__(self):
         self.name: str = 'HectoLiter'
         self.unit: str = 'hl'
-    
+
     def __repr__(self) -> str:
         return f'hl(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class kl:
+    """Kilolitre class"""
+
     def __init__(self):
         self.name: str = 'KiloLiter'
         self.unit: str = 'kl'
-    
+
     def __repr__(self) -> str:
         return f'kl(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
 
 # Length
+
+
 class mm:
+    """Millimeter class"""
+
     def __init__(self):
         self.name: str = 'MilliMeter'
         self.unit: str = 'mm'
-    
+
     def __repr__(self) -> str:
         return f'mm(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class cm:
+    """Centimeter class"""
+
     def __init__(self):
         self.name: str = 'CentiMeter'
         self.unit: str = 'cm'
-    
+
     def __repr__(self) -> str:
         return f'cm(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class dm:
+    """Decimeter class"""
+
     def __init__(self):
         self.name: str = 'DeciMeter'
         self.unit: str = 'dm'
-    
+
     def __repr__(self) -> str:
         return f'dm(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class m:
+    """Meter class"""
+
     def __init__(self):
         self.name: str = 'Meter'
         self.unit: str = 'm'
-    
+
     def __repr__(self) -> str:
         return f'm(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class dam:
+    """Decameter class"""
+
     def __init__(self):
         self.name: str = 'DekaMeter'
         self.unit: str = 'dam'
-    
+
     def __repr__(self) -> str:
         return f'dam(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class hm:
+    """Hectameter class"""
+
     def __init__(self):
         self.name: str = 'HectoMeter'
         self.unit: str = 'hm'
-    
+
     def __repr__(self) -> str:
         return f'hm(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
+
 
 class km:
+    """Kilometer class"""
+
     def __init__(self):
         self.name: str = 'KiloMeter'
         self.unit: str = 'km'
-    
+
     def __repr__(self) -> str:
         return f'km(name={self.name}, unit={self.unit})'
 
     def __str__(self) -> str:
-        return f'{self.unit}' 
+        return f'{self.unit}'
